summaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/gui/kernel/kernel.pri6
-rw-r--r--src/opengl/opengl.pro2
-rw-r--r--src/opengl/qopenglwindow.cpp (renamed from src/gui/kernel/qopenglwindow.cpp)6
-rw-r--r--src/opengl/qopenglwindow.h (renamed from src/gui/kernel/qopenglwindow.h)6
4 files changed, 10 insertions, 10 deletions
diff --git a/src/gui/kernel/kernel.pri b/src/gui/kernel/kernel.pri
index 3784abdacc..d47fd6e4e4 100644
--- a/src/gui/kernel/kernel.pri
+++ b/src/gui/kernel/kernel.pri
@@ -158,13 +158,11 @@ qtConfig(opengl) {
HEADERS += \
kernel/qplatformopenglcontext.h \
kernel/qopenglcontext.h \
- kernel/qopenglcontext_p.h \
- kernel/qopenglwindow.h
+ kernel/qopenglcontext_p.h
SOURCES += \
kernel/qplatformopenglcontext.cpp \
- kernel/qopenglcontext.cpp \
- kernel/qopenglwindow.cpp
+ kernel/qopenglcontext.cpp
}
qtConfig(shortcut) {
diff --git a/src/opengl/opengl.pro b/src/opengl/opengl.pro
index eaa10de22a..a726db2be9 100644
--- a/src/opengl/opengl.pro
+++ b/src/opengl/opengl.pro
@@ -11,9 +11,11 @@ qtConfig(opengles2): CONFIG += opengles2
HEADERS += \
qopengldebug.h \
+ qopenglwindow.h \
qtopenglglobal.h
SOURCES += \
+ qopenglwindow.cpp \
qopengldebug.cpp
!qtConfig(opengles2) {
diff --git a/src/gui/kernel/qopenglwindow.h b/src/opengl/qopenglwindow.h
index 7b3bf004a3..926e4fabfd 100644
--- a/src/gui/kernel/qopenglwindow.h
+++ b/src/opengl/qopenglwindow.h
@@ -3,7 +3,7 @@
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
-** This file is part of the QtGui module of the Qt Toolkit.
+** This file is part of the QtOpenGL module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
@@ -40,7 +40,7 @@
#ifndef QOPENGLWINDOW_H
#define QOPENGLWINDOW_H
-#include <QtGui/qtguiglobal.h>
+#include <QtOpenGL/qtopenglglobal.h>
#ifndef QT_NO_OPENGL
@@ -52,7 +52,7 @@ QT_BEGIN_NAMESPACE
class QOpenGLWindowPrivate;
-class Q_GUI_EXPORT QOpenGLWindow : public QPaintDeviceWindow
+class Q_OPENGL_EXPORT QOpenGLWindow : public QPaintDeviceWindow
{
Q_OBJECT
Q_DECLARE_PRIVATE(QOpenGLWindow)
diff --git a/src/gui/kernel/qopenglwindow.cpp b/src/opengl/qopenglwindow.cpp
index 2ea8f43711..8cdf134bfd 100644
--- a/src/gui/kernel/qopenglwindow.cpp
+++ b/src/opengl/qopenglwindow.cpp
@@ -3,7 +3,7 @@
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the QtGui module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
@@ -38,11 +38,11 @@
****************************************************************************/
#include "qopenglwindow.h"
-#include "qpaintdevicewindow_p.h"
#include <QtGui/QOpenGLFramebufferObject>
#include <QtGui/QOpenGLPaintDevice>
#include <QtGui/QOpenGLFunctions>
#include <QtGui/QOpenGLTextureBlitter>
+#include <QtGui/private/qpaintdevicewindow_p.h>
#include <QtGui/private/qopenglextensions_p.h>
#include <QtGui/private/qopenglcontext_p.h>
#include <QtGui/QMatrix4x4>
@@ -52,7 +52,7 @@ QT_BEGIN_NAMESPACE
/*!
\class QOpenGLWindow
- \inmodule QtGui
+ \inmodule QtOpenGL
\since 5.4
\brief The QOpenGLWindow class is a convenience subclass of QWindow to perform OpenGL painting.
@@ -3,7 +3,7 @@
** Contact: https://www.qt.io/licensing/
**
-** This file is part of the QtGui module of the Qt Toolkit.
+** This file is part of the QtOpenGL module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$